@@ -9,20 +9,6 @@
 #include "private/webelement.hpp"
 #include "private/webelementcollection.hpp"
 
-char* _bytearray_to_char_ptr(const QByteArray &data) {
-    char *resultData = new char[data.size() + 1];
-    qstrncpy(resultData, data.data(), data.size() + 1);
-
-    return resultData;
-}
-
-char* _qvariant_to_json_char_ptr(const QVariant &data) {
-    QJson::Serializer serializer;
-    bool ok;
-
-    return _bytearray_to_char_ptr(serializer.serialize(data, &ok));
-}
-
 extern "C" {
 
 /******* Context *******/
@@ -69,18 +55,21 @@ void ph_context_set_max_pages_in_cache(int num) {
 
 char* ph_context_get_all_cookies() {
     QJson::Serializer serializer;
-    bool ok;
-
     QVariantList cookies = ph::CookieJar::instance()->getAllCookies();
-    return _bytearray_to_char_ptr(serializer.serialize(cookies, &ok));
+
+    bool ok;
+    QByteArray data = serializer.serialize(cookies, &ok);
+
+    char *resultData = new char[data.size() + 1];
+    qstrncpy(resultData, data.data(), data.size() + 1);
+    return resultData;
 }
 
 void ph_context_set_cookies(const char *cookies) {
-    QJson::Parser parser;
-    bool ok;
+    QJsonArray cookiesArray = QJsonDocument::fromJson(QByteArray(cookies)).array();
+    QVariantList cookiesList = cookiesArray.toVariantList();
 
-    QVariant cookiesData = parser.parse(QByteArray(cookies), &ok);
-    ph::CookieJar::instance()->addCookiesFromMapList(cookiesData.toList());
+    ph::CookieJar::instance()->addCookiesFromMapList(cookiesList);
 }
 
 void ph_context_clear_cookies() {
@@ -145,7 +134,11 @@ char* ph_page_get_cookies(void *page) {
     QJson::Serializer serializer;
     bool ok;
 
-    return _bytearray_to_char_ptr(serializer.serialize(cookiesList, &ok));
+    QByteArray cookiesData = serializer.serialize(cookiesList, &ok);
+    char *resultData = new char[cookiesData.size() + 1];
+
+    qstrncpy(resultData, cookiesData.data(), cookiesData.size() + 1);
+    return resultData;
 }
 
 
@@ -156,18 +149,19 @@ char* ph_page_get_requested_urls(void *page) {
     QVariantList urls;
     QSet<QString>::const_iterator i;
 
-#ifdef PHANTOMPY_QT4
-    for(i=urlsList.begin(); i != urlsList.end(); ++i) {
-#else
     for(i=urlsList.cbegin(); i != urlsList.cend(); ++i) {
-#endif
         urls << QVariant::fromValue((*i));
     }
 
+
     QJson::Serializer serializer;
     bool ok;
 
-    return _bytearray_to_char_ptr(serializer.serialize(urls, &ok));
+    QByteArray requestedUrls = serializer.serialize(urls, &ok);
+    char *resultData = new char[requestedUrls.size() + 1];
+
+    qstrncpy(resultData, requestedUrls.data(), requestedUrls.size() + 1);
+    return resultData;
 }
 
 char* ph_page_get_reply_by_url(void *page, const char *url) {
@@ -177,7 +171,11 @@ char* ph_page_get_reply_by_url(void *page, const char *url) {
     QJson::Serializer serializer;
     bool ok;
 
-    return _bytearray_to_char_ptr(serializer.serialize(response, &ok));
+    QByteArray data = serializer.serialize(response, &ok);
+    char *resultData = new char[data.size() + 1];
+
+    qstrncpy(resultData, data.data(), data.size() + 1);
+    return resultData;
 }
 
 
@@ -206,13 +204,22 @@ void ph_frame_free(void *frame) {
 
 char* ph_frame_to_html(void *frame) {
     ph::Frame *f = (ph::Frame*)frame;
-    return _bytearray_to_char_ptr(f->toHtml().toUtf8());
+
+    QByteArray data = f->toHtml().toUtf8();
+    char *resultData = new char[data.size() + 1];
+    qstrncpy(resultData, data.data(), data.size() + 1);
+    return resultData;
 }
 
 char* ph_frame_evaluate_javascript(void *frame, char *javascript) {
     ph::Frame *f = (ph::Frame*)frame;
-    QString js = QString::fromUtf8(javascript);
-    return _qvariant_to_json_char_ptr(f->evaluateJavaScript(js));
+
+    QString js(javascript);
+    QByteArray data = f->evaluateJavaScript(js).toUtf8();
+
+    char *resultData = new char[data.size() + 1];
+    qstrncpy(resultData, data.data(), data.size() + 1);
+    return resultData;
 }
 
 void* ph_frame_find_first(void *frame, const char *selector) {
@@ -232,7 +239,11 @@ void* ph_frame_find_all(void *frame, const char *selector) {
 
 char* ph_frame_get_url(void *frame) {
     ph::Frame *f = static_cast<ph::Frame*>(frame);
-    return _bytearray_to_char_ptr(f->getUrl().toUtf8());
+
+    QByteArray data = f->getUrl().toUtf8();
+    char *resultData = new char[data.size() + 1];
+    qstrncpy(resultData, data.data(), data.size() + 1);
+    return resultData;
 }
 
 void ph_frame_set_url(void *frame, const char *url) {
@@ -314,39 +325,59 @@ void* ph_webelement_find_all(void *element, const char *selector) {
 
 char* ph_webelement_tag_name(void *element) {
     ph::WebElement *el = static_cast<ph::WebElement*>(element);
-    return _bytearray_to_char_ptr(el->tagName().toUtf8());
+
+    QByteArray data = el->tagName().toUtf8();
+
+    char *resultData = new char[data.size() + 1];
+    qstrncpy(resultData, data.data(), data.size() + 1);
+    return resultData;
 }
 
 char* ph_webelement_inner_html(void *element) {
     ph::WebElement *el = static_cast<ph::WebElement*>(element);
-    return _bytearray_to_char_ptr(el->toHtml().toUtf8());
+    QByteArray data = el->toHtml().toUtf8();
+
+    char *resultData = new char[data.size() + 1];
+    qstrncpy(resultData, data.data(), data.size() + 1);
+    return resultData;
 }
 
 char* ph_webelement_inner_text(void *element) {
     ph::WebElement *el = static_cast<ph::WebElement*>(element);
-    return _bytearray_to_char_ptr(el->toText().toUtf8());
+    QByteArray data = el->toText().toUtf8();
+
+    char *resultData = new char[data.size() + 1];
+    qstrncpy(resultData, data.data(), data.size() + 1);
+    return resultData;
 }
 
 
 char* ph_webelement_get_classes(void *element) {
     ph::WebElement *el = static_cast<ph::WebElement*>(element);
-    QByteArray data = el->getClasses().join(QString::fromUtf8(" ")).toUtf8();
+    QByteArray data = el->getClasses().join(" ").toUtf8();
+
+    char *resultData = new char[data.size() + 1];
+    qstrncpy(resultData, data.data(), data.size() + 1);
+    return resultData;
 
-    return _bytearray_to_char_ptr(data);
 }
 
 char* ph_webelement_get_attrnames(void *element) {
     ph::WebElement *el = static_cast<ph::WebElement*>(element);
-    QByteArray data = el->getAttributeNames().join(QString::fromUtf8(" ")).toUtf8();
+    QByteArray data = el->getAttributeNames().join(" ").toUtf8();
 
-    return _bytearray_to_char_ptr(data);
+    char *resultData = new char[data.size() + 1];
+    qstrncpy(resultData, data.data(), data.size() + 1);
+    return resultData;
 }
 
 char* ph_webelement_get_attr(void *element, const char *attrname) {
     ph::WebElement *el = static_cast<ph::WebElement*>(element);
     QByteArray data = el->getAttribute(QString::fromUtf8(attrname)).toUtf8();
 
-    return _bytearray_to_char_ptr(data);
+    char *resultData = new char[data.size() + 1];
+    qstrncpy(resultData, data.data(), data.size() + 1);
+    return resultData;
 }
 
 int32_t ph_webelement_has_class(void *element, const char *classname) {
@@ -480,8 +511,14 @@ void* ph_webelement_next(void *element) {
 
 char* ph_webelement_evaluate_javascript(void *element, const char *javascript) {
     ph::WebElement *el = static_cast<ph::WebElement*>(element);
-    QString js = QString::fromUtf8(javascript);
-    return _qvariant_to_json_char_ptr(el->evaluateJavaScript(js));
+
+    QString js(javascript);
+    QByteArray data = el->evaluateJavaScript(js).toUtf8();
+
+    char *resultData = new char[data.size() + 1];
+    qstrncpy(resultData, data.data(), data.size() + 1);
+    return resultData;
+
 }
 
 }
